@@ -33,9 +33,9 @@ makeAll <- function(...)
   scripts <- c("data.R", "model.R", "output.R", "report.R")
   scripts <- scripts[file.exists(scripts)]
 
-  ok <- sapply(scripts, makeTAF, ...)
-  if(length(ok) == 0)
-    ok <- logical(0)
+  out <- sapply(scripts, makeTAF, ...)
+  if(length(out) == 0)
+    out <- logical(0)
 
-  invisible(ok)
+  invisible(out)
 }
